"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const semver_1 = require("semver");
const path_1 = __importDefault(require("path"));
/**
 * Determines minimum supported node version by parsing `engines.node` value
 * from project's `package.json`.
 */
function determineNodeVersion() {
    var _a;
    let packageJson;
    try {
        packageJson = JSON.parse(fs_1.readFileSync('package.json', { encoding: 'utf-8' }));
    }
    catch (error) {
        throw new Error('Could not read package.json. Please double-check that current working ' +
            'dir is the root folder of your project.');
    }
    const supportedNodeRange = (_a = packageJson === null || packageJson === void 0 ? void 0 : packageJson.engines) === null || _a === void 0 ? void 0 : _a.node;
    if (typeof supportedNodeRange !== 'string') {
        throw new Error('Unable to determine supported node version. Package.json seems to miss ' +
            '`engines.node` key.');
    }
    const minSupportedNodeVersion = semver_1.minVersion(supportedNodeRange);
    if (!minSupportedNodeVersion) {
        throw new Error('Unable to determine supported node version. Failed to parse `engines.node` ' +
            `value from package.json as semver. It is ${supportedNodeRange}.`);
    }
    return semver_1.major(minSupportedNodeVersion).toString();
}
/**
 * Determines package manager used by project by existence of either
 * package-lock.json or yarn.lock.
 */
function determinePackageManager() {
    const isNPM = fs_1.existsSync('package-lock.json');
    const isYarn = fs_1.existsSync('yarn.lock');
    if (isNPM && isYarn) {
        throw new Error('Unable to determine package manager. Project seems to have both package-lock.json and yarn.lock.');
    }
    if (!isNPM && !isYarn) {
        throw new Error('Unable to determine package manager. Project seems to have neither package-lock.json nor yarn.lock');
    }
    return isNPM ? 'npm' : 'yarn';
}
/**
 * Determines browsers supported by project based on testem.js configuration.
 */
async function determineBrowsers() {
    var _a;
    let testemConfiguration;
    try {
        testemConfiguration = await Promise.resolve().then(() => __importStar(require(path_1.default.join(process.cwd(), 'testem.js'))));
    }
    catch (error) {
        throw new Error('Could not calculate testem configuration. Please double-check that current working ' +
            `dir is the root folder of your project.\n${error}`);
    }
    return (_a = testemConfiguration === null || testemConfiguration === void 0 ? void 0 : testemConfiguration.launch_in_ci) !== null && _a !== void 0 ? _a : ['chrome'];
}
async function determineEmberTryScenarios() {
    var _a, _b;
    let emberTryConfiguration;
    try {
        const { default: getEmberTryConfiguration } = (await Promise.resolve().then(() => __importStar(require(path_1.default.join(process.cwd(), 'config', 'ember-try.js')))));
        emberTryConfiguration = await getEmberTryConfiguration();
    }
    catch (error) {
        throw new Error('Could not determine Ember Try scenarios. Please double-check\n' +
            '  1) that current working dir is the root folder of your project and\n' +
            '  2) that all dependencies imported in config/ember-try.js are installed.\n' +
            `Error message:\n  ${error}`);
    }
    return ((_b = (_a = emberTryConfiguration === null || emberTryConfiguration === void 0 ? void 0 : emberTryConfiguration.scenarios) === null || _a === void 0 ? void 0 : _a.map(({ name }) => {
        return {
            scenario: name,
            allowedToFail: false,
        };
    })) !== null && _b !== void 0 ? _b : []);
}
async function default_1() {
    return {
        browsers: await determineBrowsers(),
        emberTryScenarios: await determineEmberTryScenarios(),
        nodeVersion: determineNodeVersion(),
        packageManager: determinePackageManager(),
    };
}
exports.default = default_1;
