"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug_1 = __importDefault(require("../utils/debug"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const js_yaml_1 = __importDefault(require("js-yaml"));
async function parsePreviousRunConfig() {
    const gitHubActionFile = path_1.default.join(process.cwd(), '.github/workflows/ci.yml');
    debug_1.default(`Looking for configuration in an existing GitHub Actions workflow at ${gitHubActionFile}`);
    let gitHubAction;
    try {
        gitHubAction = fs_1.default.readFileSync(gitHubActionFile, { encoding: 'utf-8' });
    }
    catch (error) {
        if (error.code === 'ENOENT') {
            debug_1.default('No existing GitHub Actions workflow found');
            return null;
        }
        throw error;
    }
    const previousConfigString = gitHubAction
        .split('\n')
        .filter((_) => _.startsWith('#$'))
        .map((_) => _.substr(2))
        .join('\n');
    if (previousConfigString === '') {
        debug_1.default(`GitHub Actions workflow does not seem to contain configuration used in previous run`);
        return null;
    }
    const previousConfig = js_yaml_1.default.safeLoad(previousConfigString);
    if (previousConfig === null || typeof previousConfig !== 'object') {
        debug_1.default(`Unable to parse configuration used in previous run: ${previousConfigString}`);
        return null;
    }
    const { browsers, emberTryScenarios, nodeVersion, packageManager, } = previousConfig;
    if (!['npm', 'yarn'].includes(packageManager)) {
        // TODO: warn
        debug_1.default(`Previous configuration includes invalid package manager ${packageManager}.`);
        return null;
    }
    if (!Array.isArray(browsers)) {
        // TODO: warn
        debug_1.default(`Previous configuration includes an invalid value for browsers. It should be a collection but is ${typeof browsers}`);
    }
    return {
        browsers,
        emberTryScenarios,
        nodeVersion,
        packageManager,
    };
}
exports.default = parsePreviousRunConfig;
