"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug_1 = __importDefault(require("./debug"));
const travis_ci_1 = __importDefault(require("../parser/travis-ci"));
const previous_run_1 = __importDefault(require("../parser/previous-run"));
const defaults_1 = __importDefault(require("../parser/defaults"));
const parsers = [
    {
        name: 'TravisCI',
        parse: travis_ci_1.default,
    },
    {
        name: 'Previous Run',
        parse: previous_run_1.default,
    },
    {
        name: 'Defaults',
        parse: defaults_1.default,
    },
];
async function determineConfiguration() {
    for (const parser of parsers) {
        const { name, parse } = parser;
        debug_1.default(`Trying parser ${name}`);
        const config = await parse();
        if (config === null) {
            continue;
        }
        console.log(`Using configuration from ${name}`);
        return config;
    }
    throw new Error('Unable to determine any configuration. Defaults should have been used as a last fallback. Please report this bug.');
}
exports.default = determineConfiguration;
